==> pyconnectwise-0.5.0.tar.gz: pyconnectwise-0.5.0/src/pyconnectwise/endpoints/manage/SystemManagementnetworksecuritiesEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.SystemManagementnetworksecuritiesCountEndpoint import \
    SystemManagementnetworksecuritiesCountEndpoint
from pyconnectwise.endpoints.manage.SystemManagementnetworksecuritiesIdEndpoint import \
    SystemManagementnetworksecuritiesIdEndpoint
from pyconnectwise.interfaces import IDeleteable, IGettable, IPaginateable, IPatchable, IPostable, IPuttable
from pyconnectwise.models.manage import ManagementNetworkSecurity
from pyconnectwise.responses.paginated_response import PaginatedResponse
from pyconnectwise.types import JSON, ConnectWiseAutomateRequestParams, ConnectWiseManageRequestParams, PatchRequestData


class SystemManagementnetworksecuritiesEndpoint(
    ConnectWiseEndpoint,
    IGettable[list[ManagementNetworkSecurity], ConnectWiseManageRequestParams],
    IPostable[ManagementNetworkSecurity, ConnectWiseManageRequestParams],
    IPaginateable[ManagementNetworkSecurity, ConnectWiseManageRequestParams],
):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "managementNetworkSecurities", parent_endpoint=parent_endpoint)

        self.count = self._register_child_endpoint(
            SystemManagementnetworksecuritiesCountEndpoint(client, parent_endpoint=self)
        )

    def id(self, id: int) -> SystemManagementnetworksecuritiesIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized SystemManagementnetworksecuritiesIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            SystemManagementnetworksecuritiesIdEndpoint: The initialized SystemManagementnetworksecuritiesIdEndpoint object.
        """
        child = SystemManagementnetworksecuritiesIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(
        self, page: int, page_size: int, params: ConnectWiseManageRequestParams | None = None
    ) -> PaginatedResponse[ManagementNetworkSecurity]:
        """
        Performs a GET request against the /system/managementNetworkSecurities endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[ManagementNetworkSecurity]: The initialized PaginatedResponse object.
        """
        if params:
            params["page"] = page
            params["pageSize"] = page_size
        else:
            params = {"page": page, "pageSize": page_size}
        return PaginatedResponse(
            super()._make_request("GET", params=params), ManagementNetworkSecurity, self, page, page_size, params
        )

    def get(
        self, data: JSON | None = None, params: ConnectWiseManageRequestParams | None = None
    ) -> list[ManagementNetworkSecurity]:
        """
        Performs a GET request against the /system/managementNetworkSecurities endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[ManagementNetworkSecurity]: The parsed response data.
        """
        return self._parse_many(
            ManagementNetworkSecurity, super()._make_request("GET", data=data, params=params).json()
        )

    def post(
        self, data: JSON | None = None, params: ConnectWiseManageRequestParams | None = None
    ) -> ManagementNetworkSecurity:
        """
        Performs a POST request against the /system/managementNetworkSecurities endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            ManagementNetworkSecurity: The parsed response data.
        """
        return self._parse_one(
            ManagementNetworkSecurity, super()._make_request("POST", data=data, params=params).json()
        )

==> pyconnectwise-0.5.1.tar.gz: pyconnectwise-0.5.1/src/pyconnectwise/endpoints/manage/SystemManagementnetworksecuritiesEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.SystemManagementnetworksecuritiesCountEndpoint import \
    SystemManagementnetworksecuritiesCountEndpoint
from pyconnectwise.endpoints.manage.SystemManagementnetworksecuritiesIdEndpoint import \
    SystemManagementnetworksecuritiesIdEndpoint
from pyconnectwise.interfaces import IDeleteable, IGettable, IPaginateable, IPatchable, IPostable, IPuttable
from pyconnectwise.models.manage import ManagementNetworkSecurity
from pyconnectwise.responses.paginated_response import PaginatedResponse
from pyconnectwise.types import JSON, ConnectWiseAutomateRequestParams, ConnectWiseManageRequestParams, PatchRequestData


class SystemManagementnetworksecuritiesEndpoint(
    ConnectWiseEndpoint,
    IGettable[list[ManagementNetworkSecurity], ConnectWiseManageRequestParams],
    IPostable[ManagementNetworkSecurity, ConnectWiseManageRequestParams],
    IPaginateable[ManagementNetworkSecurity, ConnectWiseManageRequestParams],
):
    def __init__(self, client, parent_endpoint=None):
        ConnectWiseEndpoint.__init__(self, client, "managementNetworkSecurities", parent_endpoint=parent_endpoint)
        IGettable.__init__(self, list[ManagementNetworkSecurity])
        IPostable.__init__(self, ManagementNetworkSecurity)
        IPaginateable.__init__(self, ManagementNetworkSecurity)

        self.count = self._register_child_endpoint(
            SystemManagementnetworksecuritiesCountEndpoint(client, parent_endpoint=self)
        )

    def id(self, id: int) -> SystemManagementnetworksecuritiesIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized SystemManagementnetworksecuritiesIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            SystemManagementnetworksecuritiesIdEndpoint: The initialized SystemManagementnetworksecuritiesIdEndpoint object.
        """
        child = SystemManagementnetworksecuritiesIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(
        self, page: int, page_size: int, params: ConnectWiseManageRequestParams | None = None
    ) -> PaginatedResponse[ManagementNetworkSecurity]:
        """
        Performs a GET request against the /system/managementNetworkSecurities endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[ManagementNetworkSecurity]: The initialized PaginatedResponse object.
        """
        if params:
            params["page"] = page
            params["pageSize"] = page_size
        else:
            params = {"page": page, "pageSize": page_size}
        return PaginatedResponse(
            super()._make_request("GET", params=params), ManagementNetworkSecurity, self, page, page_size, params
        )

    def get(
        self, data: JSON | None = None, params: ConnectWiseManageRequestParams | None = None
    ) -> list[ManagementNetworkSecurity]:
        """
        Performs a GET request against the /system/managementNetworkSecurities endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[ManagementNetworkSecurity]: The parsed response data.
        """
        return self._parse_many(
            ManagementNetworkSecurity, super()._make_request("GET", data=data, params=params).json()
        )

    def post(
        self, data: JSON | None = None, params: ConnectWiseManageRequestParams | None = None
    ) -> ManagementNetworkSecurity:
        """
        Performs a POST request against the /system/managementNetworkSecurities endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            ManagementNetworkSecurity: The parsed response data.
        """
        return self._parse_one(
            ManagementNetworkSecurity, super()._make_request("POST", data=data, params=params).json()
        )
